@@ -1,4 +1,4 @@
-test_range_Ranges <- function() {
+test_range_IntegerRanges <- function() {
   ir1 <- IRanges(c(2,5,1), c(3,7,3))
   ir2 <- IRanges(c(5,2,0), c(6,3,1))
   checkIdentical(range(ir1), IRanges(1, 7))
@@ -16,7 +16,7 @@ test_range_Ranges <- function() {
   checkIdentical(mcols(range(ir3, with.revmap=TRUE))$revmap, IntegerList())
 }
 
-test_range_RangesList <- function() {
+test_range_IntegerRangesList <- function() {
   for (compress in c(TRUE, FALSE)) {
     rl1 <- IRangesList(a = IRanges(c(1,2),c(4,3)), b = IRanges(c(4,6),c(10,7)),
                        compress = compress)
@@ -52,7 +52,7 @@ test_range_RangesList <- function() {
   checkIdentical(mcols(rng[[2]])$revmap, IntegerList())
 }
 
-test_reduce_Ranges <- function() {
+test_reduce_IntegerRanges <- function() {
   x <- IRanges()
   current <- reduce(x)
   checkIdentical(x, current)
@@ -139,7 +139,7 @@ test_reduce_Ranges <- function() {
   checkIdentical(y9, IRanges(start=-10, end=9))
 }
 
-test_reduce_RangesList <- function() {
+test_reduce_IntegerRangesList <- function() {
   range1 <- IRanges(start=c(1,2,3), end=c(5,2,8))
   range2 <- IRanges(start=c(15,45,20,1), end=c(15,100,80,5))
   range3 <- IRanges(start=c(3,-2,6,7,-10,-2,3), width=c(1,0,0,0,0,8,0))
@@ -173,7 +173,7 @@ test_reduce_RangesList <- function() {
   }
 }
 
-test_gaps_Ranges <- function() {
+test_gaps_IntegerRanges <- function() {
   checkIdentical(gaps(IRanges()), IRanges())
   checkIdentical(gaps(IRanges(), start=1, end=4),
                  IRanges(start=1, end=4))
@@ -189,7 +189,7 @@ test_gaps_Ranges <- function() {
   checkIdentical(gaps(x, start=0, end=5), IRanges(start=c(0,4), end=c(1,5)))
 }
 
-test_gaps_RangesList <- function() {
+test_gaps_IntegerRangesList <- function() {
   range1 <- IRanges(start=c(1,2,3), end=c(5,2,8))
   range2 <- IRanges(start=c(15,45,20,1), end=c(15,100,80,5))
   for (compress in c(TRUE, FALSE)) {
@@ -200,7 +200,7 @@ test_gaps_RangesList <- function() {
   }
 }
 
-test_disjoin_Ranges <- function()
+test_disjoin_IntegerRanges <- function()
 {
   checkIdentical(disjoin(IRanges()), IRanges())
   ir <- IRanges(c(1, 21, 10, 1, 15, 5, 20, 20), c(6, 20, 9, 3, 14, 11, 20, 19))
@@ -238,7 +238,7 @@ test_disjoin_Ranges <- function()
   check_disjoin_general_properties(disjoin(ir), ir)
 }
 
-test_disjoin_RangesList <- function()
+test_disjoin_IntegerRangesList <- function()
 {
     ir0 <- IRanges(10, 20)
     checkTrue(validObject(disjoin(IRangesList())))
@@ -304,7 +304,7 @@ test_disjoin_RangesList <- function()
     }
 }
 
-test_disjointBins_Ranges <- function()
+test_disjointBins_IntegerRanges <- function()
 {
   checkIdentical(disjointBins(IRanges()), integer())
   checkIdentical(disjointBins(IRanges(1, 5)), 1L)
