@@ -1,4 +1,4 @@
-test_shift_Ranges <- function() {
+test_shift_IntegerRanges <- function() {
   ir0 <- IRanges(0, 0)
 
   ir1 <- shift(ir0, .Machine$integer.max)
@@ -31,14 +31,14 @@ test_shift_Ranges <- function() {
   checkException(suppressWarnings(shift(ir4, 1:20 * 99000000L)), silent=TRUE)
 }
 
-test_narrow_Ranges <- function() {
+test_narrow_IntegerRanges <- function() {
   ir1 <- IRanges(c(2,5,1), c(3,7,3))
   checkIdentical(narrow(ir1, start=1, end=2),
                  IRanges(c(2, 5, 1), c(3, 6, 2)))
   checkException(narrow(ir1, start=10, end=20), silent = TRUE)
 }
 
-test_narrow_RangesList <- function() {
+test_narrow_IRangesList <- function() {
   range1 <- IRanges(start=c(2,5), end=c(3,7))
   range2 <- IRanges(start=1, end=3)
   for (compress in c(TRUE, FALSE)) {
@@ -50,7 +50,7 @@ test_narrow_RangesList <- function() {
   }
 }
 
-test_resize_Ranges <- function() {
+test_resize_IntegerRanges <- function() {
   ir1 <- IRanges(c(2,5,1), c(3,7,3))
   checkIdentical(resize(ir1, width=10),
                  IRanges(c(2, 5, 1), width=10))
@@ -63,7 +63,7 @@ test_resize_Ranges <- function() {
   checkException(resize(ir1, -1), silent = TRUE)
 }
 
-test_resize_RangesList <- function() {
+test_resize_IRangesList <- function() {
   range1 <- IRanges(start=c(2,5), end=c(3,7))
   range2 <- IRanges(start=1, end=3)
   for (compress in c(TRUE, FALSE)) {
@@ -85,7 +85,7 @@ test_resize_RangesList <- function() {
   }
 }
 
-test_flank_Ranges <- function() {
+test_flank_IntegerRanges <- function() {
   checkIdentical(flank(IRanges(), 2), IRanges())
 
   ir1 <- IRanges(c(2, 5, 1), c(3, 7, 3))
@@ -103,7 +103,7 @@ test_flank_Ranges <- function() {
   checkException(flank(ir1, NA), silent = TRUE)
 }
 
-test_flank_RangesList <- function() {
+test_flank_IRangesList <- function() {
   range1 <- IRanges(start=c(2,5), end=c(3,7))
   range2 <- IRanges(start=1, end=3)
   for (compress in c(TRUE, FALSE)) {
@@ -147,30 +147,30 @@ test_promoters <- function() {
   ir <- IRanges(c(5, 2, 20), width=1)
   checkIdentical(start(promoters(ir, 5, 2)), c(0L, -3L, 15L))
 
-  rl <- RangesList("A"=IRanges(5:7, width=1), "B"=IRanges(10:12, width=5))
-  current <- promoters(rl, 0, 0) 
+  rl <- IRangesList("A"=IRanges(5:7, width=1), "B"=IRanges(10:12, width=5))
+  current <- promoters(rl, 0, 0)
   checkIdentical(names(current), names(rl))
   checkIdentical(start(current), start(rl))
-  current <- promoters(rl, 2, 0) 
+  current <- promoters(rl, 2, 0)
   checkIdentical(unique(unlist(width(current))), 2L)
 
   library(XVector)
   subject <- XInteger(10, 3:-6)
   view <- Views(subject, start=4:2, end=4:6)
-  current <- promoters(view, 0, 0) 
+  current <- promoters(view, 0, 0)
   checkIdentical(start(current), start(view))
-  current <- promoters(view, 2, 0) 
+  current <- promoters(view, 2, 0)
   checkIdentical(unique(width(current)), 2L)
- 
+
   cmp <- IRangesList("A"=IRanges(5:7, width=1), "B"=IRanges(10:12, width=5))
-  current <- promoters(rl, 0, 0) 
+  current <- promoters(rl, 0, 0)
   checkIdentical(names(current), names(rl))
   checkIdentical(start(current), start(rl))
-  current <- promoters(rl, 2, 0) 
+  current <- promoters(rl, 2, 0)
   checkIdentical(unique(unlist(width(current))), 2L)
 }
 
-test_reflect_Ranges <- function() {
+test_reflect_IntegerRanges <- function() {
   ir1 <- IRanges(c(2,5,1), c(3,7,3))
   bounds <- IRanges(c(0, 5, 3), c(10, 6, 9))
   checkIdentical(reflect(ir1, bounds),
@@ -178,7 +178,7 @@ test_reflect_Ranges <- function() {
   checkException(reflect(ir1, IRanges()), silent = TRUE)
 }
 
-test_restrict_Ranges <- function() {
+test_restrict_IntegerRanges <- function() {
   ir1 <- IRanges(c(2,5,1), c(3,7,3))
   checkIdentical(restrict(ir1, start=2, end=5),
                  IRanges(c(2, 5, 2), c(3, 5, 3)))
@@ -188,7 +188,7 @@ test_restrict_Ranges <- function() {
                  IRanges(c(2, 3, 1), c(2, 2, 2)))
 }
 
-test_restrict_RangesList <- function() {
+test_restrict_IRangesList <- function() {
   range1 <- IRanges(start=c(2,5), end=c(3,7))
   range2 <- IRanges(start=1, end=3)
   for (compress in c(TRUE, FALSE)) {
@@ -205,7 +205,7 @@ test_restrict_RangesList <- function() {
   }
 }
 
-test_zoom_Ranges <- function() {
+test_zoom_IntegerRanges <- function() {
   ir <- IRanges(c(1,5), c(3,10))
   checkIdentical(ir*1, ir)
   checkIdentical(ir*c(1,2), IRanges(c(1,6), c(3, 8)))
