@@ -8,10 +8,10 @@
 static const R_CallMethodDef callMethods[] = {
 
 /* Ranges_class.c */
-	CALLMETHOD_DEF(valid_Ranges, 3),
+	CALLMETHOD_DEF(Ranges_validate, 3),
 
-/* Ranges_comparison.c */
-	CALLMETHOD_DEF(Ranges_pcompare, 4),
+/* IPosRanges_comparison.c */
+	CALLMETHOD_DEF(IPosRanges_pcompare, 4),
 
 /* IRanges_class.c */
 	CALLMETHOD_DEF(IRanges_isNormal, 1),
@@ -47,11 +47,11 @@ static const R_CallMethodDef callMethods[] = {
 
 /* inter_range_methods.c */
 	CALLMETHOD_DEF(IRanges_range, 1),
-	CALLMETHOD_DEF(Ranges_reduce, 6),
+	CALLMETHOD_DEF(IntegerRanges_reduce, 6),
 	CALLMETHOD_DEF(CompressedIRangesList_reduce, 4),
 	CALLMETHOD_DEF(IRanges_gaps, 4),
 	CALLMETHOD_DEF(CompressedIRangesList_gaps, 3),
-	CALLMETHOD_DEF(Ranges_disjointBins, 2),
+	CALLMETHOD_DEF(IntegerRanges_disjointBins, 2),
 
 /* coverage_methods.c */
 	CALLMETHOD_DEF(IRanges_coverage, 6),
@@ -89,6 +89,9 @@ static const R_CallMethodDef callMethods[] = {
 	CALLMETHOD_DEF(CompressedIntegerList_is_unsorted, 3),
 	CALLMETHOD_DEF(CompressedNumericList_is_unsorted, 3),
 
+/* extractListFragments.c */
+	CALLMETHOD_DEF(find_partition_overlaps, 3),
+
 	{NULL, NULL, 0}
 };
 
@@ -97,7 +100,7 @@ void R_init_IRanges(DllInfo *info)
 {
 	R_registerRoutines(info, NULL, callMethods, NULL, NULL);
 
-/* Ranges_comparison.c */
+/* IPosRanges_comparison.c */
 	REGISTER_CCALLABLE(_overlap_code);
 	REGISTER_CCALLABLE(_invert_overlap_code);
 
